@@ -14,15 +14,18 @@ def test_likely_distro():
 
 def test_group_and_select_packages():
     pkgs = [
-        ['foo-1.3.tar.gz', 'bar-0.1.tar.gz'],
-        ['foo-1.4.tar.gz'],
-        [
+        ('requirements1.txt', ['foo-1.3.tar.gz', 'bar-0.1.tar.gz']),
+        ('requirements2.txt', ['foo-1.4.tar.gz', 'bar-0.1.tar.gz']),
+        ('requirements3.txt', [
             'baz-2014-01-29-16-44-48.878536.tar.gz',
             'baz-2013-01-29-16-44-48.878536.tar.gz', 
-        ],
+        ]),
     ]
     assert_equal(group_and_select_packages(pkgs), {
-        'foo': ['1.4', '1.3'],
-        'bar': ['0.1'],
-        'baz': ['2014-01-29-16-44-48.878536', '2013-01-29-16-44-48.878536'],
+        'foo': [('1.3', ['requirements1.txt']), ('1.4', ['requirements2.txt'])],
+        'bar': [('0.1', ['requirements1.txt', 'requirements2.txt'])],
+        'baz': [
+            ('2013-01-29-16-44-48.878536', ['requirements3.txt']),
+            ('2014-01-29-16-44-48.878536', ['requirements3.txt']),
+        ],
     })
